@@ -1,3 +1,5 @@
+import uuid
+
 from django import forms
 
 from django.forms import ChoiceField
@@ -552,25 +554,35 @@ class DataTransform(forms.ModelForm):
                     queryset=self.instance.get_children(),
                     data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None,
-                    initial=[{'parent': self.instance, }]
+                    initial=[{'parent': self.instance, 'accessory':self.instance.accessory, 'id':str(uuid.uuid4())}]
                 )
-                self.nested_constants_form = DataConstantsTransformerInlineFormset(
+            else:
+                dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
+                                                                     fk_name='parent', form=DataTransform,
+                                                                     extra=0
+                                                                     )
+                self.nested_data_transformer_form = dataTransformerInlineFormset(
                     instance=self.instance,
                     data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None
                 )
+            self.nested_constants_form = DataConstantsTransformerInlineFormset(
+                instance=self.instance,
+                data=self.data if self.is_bound else None,
+                files=self.files if self.is_bound else None
+            )
 
-                self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
-                    instance=self.instance,
-                    data=self.data if self.is_bound else None,
-                    files=self.files if self.is_bound else None
-                )
+            self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
+                instance=self.instance,
+                data=self.data if self.is_bound else None,
+                files=self.files if self.is_bound else None
+            )
 
-                self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
-                    instance=self.instance,
-                    data=self.data if self.is_bound else None,
-                    files=self.files if self.is_bound else None
-                )
+            self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
+                instance=self.instance,
+                data=self.data if self.is_bound else None,
+                files=self.files if self.is_bound else None
+            )
         except Exception:
             print('excpt')
 
@@ -595,6 +607,19 @@ class DataTransform(forms.ModelForm):
 
         return mark_safe(forms)
 
+    def save(self, commit=True):
+        print('node')
+        print('save: ' + str(self.instance.id))
+        super(DataTransform, self).save(commit)
+        if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
+            self.nested_constants_form.save()
+        if hasattr(self, 'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
+            self.nested_hardware_outputs_form.save()
+        if hasattr(self, 'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
+            self.nested_hardware_stats_form.save()
+        if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
+            self.nested_data_transformer_form.save()
+
     class Meta:
         model = DataTransformer
         fields = ['id', 'accessory', 'parent', 'type']
@@ -613,21 +638,35 @@ class DataTransformRoot(forms.ModelForm):
     #     super(HardwareTypeForm, self).__init__(*args, **kwargs)
     def __init__(self, *args, **kwargs):
         super(DataTransformRoot, self).__init__(*args, **kwargs)
-        print('Adding to root form node: ' + str(self.instance.get_children().count() + 1))
         types = list(
             DataTransformerTypes.objects.all().values_list('type', 'type'))
         self.fields['type'] = ChoiceField(choices=tuple(types))
+        try:
+            if hasattr(self.instance, 'get_children'):
+                print('Adding to root form node: ' + str(self.instance.get_children().count() + 1))
 
-        dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
-                                                             fk_name='parent', form=DataTransform,
-                                                             extra=self.instance.get_children().count() + 1
-                                                             )
-        self.nested_data_transformer_form = dataTransformerInlineFormset(
-            queryset=self.instance.get_children(),
-            data=self.data if self.is_bound else None,
-            files=self.files if self.is_bound else None,
-            initial=[{'parent': self.instance, }]
-        )
+                dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
+                                                                     fk_name='parent', form=DataTransform,
+                                                                     extra=self.instance.get_children().count() + 1
+                                                                     )
+                self.nested_data_transformer_form = dataTransformerInlineFormset(
+                    queryset=self.instance.get_children(),
+                    data=self.data if self.is_bound else None,
+                    files=self.files if self.is_bound else None,
+                    initial=[{'parent': self.instance, 'accessory':self.instance.accessory, 'id':str(uuid.uuid4())}]
+                )
+            else:
+                dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
+                                                                     fk_name='parent', form=DataTransform,
+                                                                     extra=0
+                                                                     )
+                self.nested_data_transformer_form = dataTransformerInlineFormset(
+                    instance=self.instance,
+                    data=self.data if self.is_bound else None,
+                    files=self.files if self.is_bound else None
+                )
+        except Exception:
+            print('exception')
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
             instance=self.instance,
@@ -666,18 +705,7 @@ class DataTransformRoot(forms.ModelForm):
         forms = forms + '</div></div>'
         return mark_safe(forms)
 
-    def save(self, commit=True):
-        print('root')
-        print('save: ' + str(self.instance.id))
-        super(DataTransformRoot, self).save(commit)
-        if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
-            self.nested_constants_form.save()
-        if hasattr(self, 'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
-            self.nested_hardware_outputs_form.save()
-        if hasattr(self, 'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
-            self.nested_hardware_stats_form.save()
-        if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
-            self.nested_data_transformer_form.save()
+
 
     def save(self, commit=True):
         print('root')
