@@ -430,7 +430,8 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         # some error occured
         return JsonResponse({"error": ""}, status=400)
 
-    def postDataTransformer(request):
+    def postDataTransformer(request, accessory_id):
+        print(str(request.POST))
         print('post data transformer')
         # request should be ajax and method should be POST.
         form = DataTransformRoot(request.POST)
